From f76fee63ed9cb3a30d3c0c092d860b1cb93a481b Mon Sep 17 00:00:00 2001
From: Gerard Smyth <gerard.smyth@gmail.com>
Date: Thu, 08 May 2014 13:09:30 -0400
Subject: [PATCH] Updated the SyndicationServlet to provide an additional option to return details of the tags in the repository instead of the commits. This uses a new 'ot' request parameter to indicate the object type of the content to return, which can be ither TAG or COMMIT. If this is not provided, then COMMIT is assumed to maintain backwards compatability. If tags are returned, then the paging parameters, 'l' and 'pg' are still supported, but searching options are currently ignored.
---
src/main/java/com/gitblit/service/LuceneService.java | 14 +++++++-------
1 files changed, 7 insertions(+), 7 deletions(-)
diff --git a/src/main/java/com/gitblit/service/LuceneService.java b/src/main/java/com/gitblit/service/LuceneService.java
index 70e3b24..482be5c 100644
--- a/src/main/java/com/gitblit/service/LuceneService.java
+++ b/src/main/java/com/gitblit/service/LuceneService.java
@@ -194,7 +194,7 @@
* Synchronously indexes a repository. This may build a complete index of a
* repository or it may update an existing index.
*
- * @param name
+ * @param displayName
* the name of the repository
* @param repository
* the repository object
@@ -437,7 +437,7 @@
// skip non-annotated tags
continue;
}
- if (!tags.containsKey(tag.getObjectId())) {
+ if (!tags.containsKey(tag.getObjectId().getName())) {
tags.put(tag.getReferencedObjectId().getName(), new ArrayList<String>());
}
tags.get(tag.getReferencedObjectId().getName()).add(tag.displayName);
@@ -476,8 +476,8 @@
&& branch.equals(defaultBranch)) {
// indexing "default" branch
indexBranch = true;
- } else if (branch.getName().startsWith(com.gitblit.Constants.R_GITBLIT)) {
- // skip Gitblit internal branches
+ } else if (branch.getName().startsWith(com.gitblit.Constants.R_META)) {
+ // skip internal meta branches
indexBranch = false;
} else {
// normal explicit branch check
@@ -760,7 +760,7 @@
// skip non-annotated tags
continue;
}
- if (!tags.containsKey(tag.getObjectId())) {
+ if (!tags.containsKey(tag.getObjectId().getName())) {
tags.put(tag.getReferencedObjectId().getName(), new ArrayList<String>());
}
tags.get(tag.getReferencedObjectId().getName()).add(tag.displayName);
@@ -807,8 +807,8 @@
&& branch.equals(defaultBranch)) {
// indexing "default" branch
indexBranch = true;
- } else if (branch.getName().startsWith(com.gitblit.Constants.R_GITBLIT)) {
- // ignore internal Gitblit branches
+ } else if (branch.getName().startsWith(com.gitblit.Constants.R_META)) {
+ // ignore internal meta branches
indexBranch = false;
} else {
// normal explicit branch check
--
Gitblit v1.9.1